@@ -1297,9 +1297,7 @@ EventHandler<ClientTypes, StateEnum::ExpectingServerHello, Event::ServerHello>::
   }
 
   // Servers cannot accept GREASE PSK
-  if (echStatus == ECHStatus::Rejected &&
-      (negotiatedPsk.type == PskType::External ||
-       negotiatedPsk.type == PskType::Resumption)) {
+  if (echStatus == ECHStatus::Rejected && isPskAccepted(negotiatedPsk.type)) {
     throw FizzException(
         "ech rejected but server accepted psk",
         AlertDescription::illegal_parameter);
@@ -1346,10 +1344,12 @@ EventHandler<ClientTypes, StateEnum::ExpectingServerHello, Event::ServerHello>::
       folly::IOBuf::copyBuffer(handshakeReadSecret.secret);
 
   folly::Optional<ClientAuthType> authType;
-  if (negotiatedPsk.clientCert) {
-    authType = ClientAuthType::Stored;
-  } else if (negotiatedPsk.serverCert) {
-    authType = ClientAuthType::NotRequested;
+  if (isPskAccepted(negotiatedPsk.type)) {
+    if (negotiatedPsk.clientCert) {
+      authType = ClientAuthType::Stored;
+    } else {
+      authType = ClientAuthType::NotRequested;
+    }
   }
 
   std::chrono::system_clock::time_point handshakeTime;
@@ -1779,11 +1779,15 @@ Actions EventHandler<
   }
 
   folly::Optional<std::vector<ech::ECHConfig>> retryConfigs;
+  folly::Optional<ECHRetryAvailable> echRetryAvailable;
   if (state.echState().has_value()) {
     // Check if we were sent retry configs
     auto serverECH = getExtension<ech::ECHEncryptedExtensions>(ee.extensions);
     if (serverECH.has_value()) {
       retryConfigs = std::move(serverECH->retry_configs);
+      echRetryAvailable = ECHRetryAvailable{};
+      echRetryAvailable->sni = state.echState()->sni.value_or("");
+      echRetryAvailable->configs = retryConfigs.value();
     }
   }
 
@@ -1791,7 +1795,8 @@ Actions EventHandler<
     state.extensions()->onEncryptedExtensions(ee.extensions);
   }
 
-  MutateState mutateState(
+  Actions ret;
+  ret.emplace_back(MutateState(
       [appProto = std::move(appProto),
        earlyDataType,
        retryConfigs = std::move(retryConfigs)](State& newState) mutable {
@@ -1801,50 +1806,41 @@ Actions EventHandler<
         if (retryConfigs.has_value()) {
           newState.echState()->retryConfigs = std::move(retryConfigs);
         }
-      });
+      }));
 
-  if (state.pskType() == PskType::Resumption ||
-      state.pskType() == PskType::External) {
-    return actions(
-        std::move(mutateState),
-        MutateState(&Transition<StateEnum::ExpectingFinished>));
-  } else {
-    return actions(
-        std::move(mutateState),
-        MutateState(&Transition<StateEnum::ExpectingCertificate>));
+  if (echRetryAvailable) {
+    ret.emplace_back(std::move(*echRetryAvailable));
   }
+
+  auto nextState = (isPskAccepted(*state.pskType()))
+      ? &Transition<StateEnum::ExpectingFinished>
+      : &Transition<StateEnum::ExpectingCertificate>;
+  ret.emplace_back(MutateState(nextState));
+
+  return ret;
 }
 
-static std::tuple<
-    folly::Optional<SignatureScheme>,
-    std::shared_ptr<const SelfCert>>
-getClientCert(const State& state, const std::vector<SignatureScheme>& schemes) {
-  folly::Optional<SignatureScheme> selectedScheme;
-  auto clientCert = state.context()->getClientCertificate();
+static folly::Optional<
+    std::pair<std::shared_ptr<const SelfCert>, SignatureScheme>>
+getClientCert(
+    const State& state,
+    const std::vector<SignatureScheme>& schemes,
+    const std::vector<Extension>& peerExtensions) {
+  auto certManager = state.context()->getCertManager();
+  if (certManager == nullptr) {
+    return folly::none;
+  }
   const auto& supportedSchemes = state.context()->getSupportedSigSchemes();
-
-  if (clientCert) {
-    const auto certSchemes = clientCert->getSigSchemes();
-    for (const auto& scheme : supportedSchemes) {
-      if (std::find(certSchemes.begin(), certSchemes.end(), scheme) !=
-              certSchemes.end() &&
-          std::find(schemes.begin(), schemes.end(), scheme) != schemes.end()) {
-        selectedScheme = scheme;
-        break;
-      }
-    }
-
-    if (!selectedScheme) {
-      VLOG(1) << "client cert/context doesn't support any signature algorithms "
-              << "specified by the server";
-    }
+  auto result = certManager->getCert(
+      state.sni(), supportedSchemes, schemes, peerExtensions);
+  if (!result) {
+    VLOG(1) << "client cert/context doesn't support any signature algorithms "
+            << "specified by the server";
+    return folly::none;
   }
 
-  if (!selectedScheme) {
-    clientCert = nullptr;
-  }
-
-  return std::make_tuple(std::move(selectedScheme), std::move(clientCert));
+  std::shared_ptr<const SelfCert> cert = result->cert;
+  return std::make_pair(cert, result->scheme);
 }
 
 Actions EventHandler<
@@ -1874,12 +1870,19 @@ Actions EventHandler<
         AlertDescription::illegal_parameter);
   }
 
+  auto certAndScheme = getClientCert(
+      state,
+      sigAlgsExtension->supported_signature_algorithms,
+      certRequest.extensions);
+
   folly::Optional<SignatureScheme> scheme;
   std::shared_ptr<const SelfCert> cert;
-  std::tie(scheme, cert) =
-      getClientCert(state, sigAlgsExtension->supported_signature_algorithms);
-  ClientAuthType authType =
-      scheme ? ClientAuthType::Sent : ClientAuthType::RequestedNoMatch;
+  ClientAuthType authType = ClientAuthType::RequestedNoMatch;
+
+  if (certAndScheme.hasValue()) {
+    std::tie(cert, scheme) = *certAndScheme;
+    authType = ClientAuthType::Sent;
+  }
 
   MutateState mutateState([scheme = std::move(scheme),
                            cert = std::move(cert),
@@ -2306,7 +2309,7 @@ EventHandler<ClientTypes, StateEnum::Established, Event::AppWrite>::handle(
   auto& appWrite = *param.asAppWrite();
 
   WriteToSocket write;
-  write.callback = appWrite.callback;
+  write.token = appWrite.token;
   write.contents.emplace_back(state.writeRecordLayer()->writeAppData(
       std::move(appWrite.data), appWrite.aeadOptions));
   write.flags = appWrite.flags;
@@ -2448,7 +2451,7 @@ static Actions handleEarlyAppWrite(const State& state, EarlyAppWrite appWrite) {
     case EarlyDataType::Attempted:
     case EarlyDataType::Accepted: {
       WriteToSocket write;
-      write.callback = appWrite.callback;
+      write.token = appWrite.token;
       write.flags = appWrite.flags;
       auto appData = state.earlyWriteRecordLayer()->writeAppData(
           std::move(appWrite.data), appWrite.aeadOptions);
@@ -2518,7 +2521,7 @@ EventHandler<ClientTypes, StateEnum::Established, Event::EarlyAppWrite>::handle(
     // the early data was accepted, otherwise we need to ignore them to preserve
     // the all-or-nothing property of early data.
     WriteToSocket write;
-    write.callback = appWrite.callback;
+    write.token = appWrite.token;
     write.contents.emplace_back(state.writeRecordLayer()->writeAppData(
         std::move(appWrite.data), appWrite.aeadOptions));
     write.flags = appWrite.flags;
