@@ -8,7 +8,7 @@
 
 #include <gtest/gtest.h>
 
-#include <fizz/crypto/Sha256.h>
+#include <fizz/backend/openssl/OpenSSL.h>
 #include <fizz/crypto/aead/test/TestUtil.h>
 #include <fizz/crypto/hpke/Context.h>
 #include <fizz/crypto/hpke/Utils.h>
@@ -162,7 +162,7 @@ TEST_P(HpkeContextTest, TestExportSecretThrow) {
         HashFunction::Sha256,
         CipherSuite::TLS_AES_128_GCM_SHA256);
     HpkeContextImpl context(
-        OpenSSLEVPCipher::makeCipher<AESGCM128>(),
+        openssl::OpenSSLEVPCipher::makeCipher<fizz::AESGCM128>(),
         toIOBuf(testParam.exporterSecret),
         std::make_unique<fizz::hpke::Hkdf>(
             kPrefix->clone(),
