@@ -8,8 +8,8 @@
 
 #include <folly/portability/GTest.h>
 
+#include <fizz/backend/openssl/OpenSSL.h>
 #include <fizz/crypto/Hkdf.h>
-#include <fizz/crypto/Sha256.h>
 #include <fizz/crypto/test/TestUtil.h>
 
 namespace fizz {
