@@ -8,8 +8,8 @@
 
 #include <folly/portability/GTest.h>
 
+#include <fizz/backend/openssl/OpenSSL.h>
 #include <fizz/crypto/KeyDerivation.h>
-#include <fizz/crypto/Sha256.h>
 #include <folly/String.h>
 #include <folly/io/IOBuf.h>
 
@@ -60,7 +60,8 @@ TEST(KeyDerivation, Sha256BlankHash) {
   std::vector<uint8_t> computed(
       KeyDerivationImpl::create<Sha256>(kHkdfLabelPrefix.str()).hashLength());
   folly::IOBuf blankBuf;
-  Sha256::hash(blankBuf, MutableByteRange(computed.data(), computed.size()));
+  openssl::Hasher<Sha256>::hash(
+      blankBuf, MutableByteRange(computed.data(), computed.size()));
   EXPECT_EQ(
       StringPiece(KeyDerivationImpl::create<Sha256>(kHkdfLabelPrefix.str())
                       .blankHash()),
