@@ -8,6 +8,7 @@
 
 #pragma once
 
+#include <fizz/protocol/Certificate.h>
 #include <fizz/protocol/KeyScheduler.h>
 #include <fizz/record/Types.h>
 #include <folly/io/IOBufIovecBuilder.h>
@@ -17,8 +18,6 @@
 
 namespace fizz {
 
-using Cert = folly::AsyncTransportCertificate;
-
 /**
  * This class is a wrapper around AsyncTransportWrapper to handle most app level
  * interactions. The derived client and server classes utilize the protected
@@ -201,9 +200,9 @@ class AsyncFizzBase : public folly::WriteChainAsyncTransportWrapper<
   /**
    * Get the certificates in fizz::Cert form.
    */
-  const Cert* getPeerCertificate() const override = 0;
+  const fizz::Cert* getPeerCertificate() const override = 0;
 
-  const Cert* getSelfCertificate() const override = 0;
+  const fizz::Cert* getSelfCertificate() const override = 0;
 
   bool isReplaySafe() const override = 0;
   void setReplaySafetyCallback(
@@ -584,6 +583,7 @@ class AsyncFizzBase : public folly::WriteChainAsyncTransportWrapper<
 
   ReadCallback* readCallback_{nullptr};
   std::unique_ptr<folly::IOBuf> appDataBuf_;
+  folly::Optional<folly::AsyncSocketException> pendingReadEx_;
 
   size_t appBytesWritten_{0};
   size_t appBytesReceived_{0};
