@@ -22,7 +22,6 @@
 #include <fizz/record/EncryptedRecordLayer.h>
 #include <fizz/record/PlaintextRecordLayer.h>
 #include <fizz/record/Types.h>
-#include <folly/io/async/AsyncTransportCertificate.h>
 
 namespace fizz {
 
@@ -72,12 +71,12 @@ class Factory {
   [[nodiscard]] virtual std::unique_ptr<folly::IOBuf> makeRandomBytes(
       size_t count) const = 0;
 
-  virtual std::shared_ptr<PeerCert> makePeerCert(
+  virtual std::unique_ptr<PeerCert> makePeerCert(
       CertificateEntry certEntry,
       bool /*leaf*/) const = 0;
 
-  [[nodiscard]] virtual std::shared_ptr<folly::AsyncTransportCertificate>
-  makeIdentityOnlyCert(std::string ident) const = 0;
+  [[nodiscard]] virtual std::shared_ptr<Cert> makeIdentityOnlyCert(
+      std::string ident) const = 0;
 
   [[nodiscard]] virtual std::string getHkdfPrefix() const = 0;
 };
