@@ -8,6 +8,7 @@
 
 #pragma once
 
+#include <fizz/backend/openssl/OpenSSLFactory.h>
 #include <fizz/crypto/aead/test/Mocks.h>
 #include <fizz/crypto/exchange/test/Mocks.h>
 #include <fizz/crypto/test/Mocks.h>
@@ -16,7 +17,6 @@
 #include <fizz/protocol/CertificateVerifier.h>
 #include <fizz/protocol/HandshakeContext.h>
 #include <fizz/protocol/KeyScheduler.h>
-#include <fizz/protocol/OpenSSLFactory.h>
 #include <fizz/protocol/Types.h>
 #include <fizz/protocol/ech/Decrypter.h>
 #include <fizz/record/test/Mocks.h>
@@ -62,6 +62,15 @@ class MockKeyScheduler : public KeyScheduler {
       getTrafficKey,
       (folly::ByteRange trafficSecret, size_t keyLength, size_t ivLength),
       (const));
+  MOCK_METHOD(
+      TrafficKey,
+      getTrafficKeyWithLabel,
+      (folly::ByteRange trafficSecret,
+       folly::StringPiece keyLabel,
+       folly::StringPiece ivLabel,
+       size_t keyLength,
+       size_t ivLength),
+      (const));
   MOCK_METHOD(
       Buf,
       getResumptionSecret,
@@ -74,6 +83,12 @@ class MockKeyScheduler : public KeyScheduler {
           return TrafficKey{
               folly::IOBuf::copyBuffer("key"), folly::IOBuf::copyBuffer("iv")};
         }));
+    ON_CALL(*this, getTrafficKeyWithLabel(_, _, _, _, _))
+        .WillByDefault(InvokeWithoutArgs([]() {
+          return TrafficKey{
+              folly::IOBuf::copyBuffer("key_with_label"),
+              folly::IOBuf::copyBuffer("iv_with_label")};
+        }));
     ON_CALL(*this, getResumptionSecret(_, _))
         .WillByDefault(InvokeWithoutArgs(
             []() { return folly::IOBuf::copyBuffer("resumesecret"); }));
@@ -103,7 +118,13 @@ class MockKeyScheduler : public KeyScheduler {
         }));
     ON_CALL(*this, getSecret(_))
         .WillByDefault(Invoke([](AppTrafficSecrets type) {
-          return DerivedSecret(std::vector<uint8_t>(), type);
+          // The app traffic secret should be 32 bytes
+          return DerivedSecret(
+              std::vector<uint8_t>({'a', 'p', 'p', 't', 'r', 'a', 'f', 'f',
+                                    'i', 'c', 'a', 'p', 'p', 't', 'r', 'a',
+                                    'f', 'f', 'i', 'c', 'a', 'p', 'p', 't',
+                                    'r', 'a', 'f', 'f', 'i', 'c', '3', '2'}),
+              type);
         }));
   }
 };
@@ -182,7 +203,7 @@ class MockPeerCert : public PeerCert {
 class MockCertificateVerifier : public CertificateVerifier {
  public:
   MOCK_METHOD(
-      std::shared_ptr<const folly::AsyncTransportCertificate>,
+      std::shared_ptr<const Cert>,
       verify,
       (const std::vector<std::shared_ptr<const PeerCert>>&),
       (const));
@@ -194,7 +215,7 @@ class MockCertificateVerifier : public CertificateVerifier {
       (const));
 };
 
-class MockFactory : public OpenSSLFactory {
+class MockFactory : public openssl::OpenSSLFactory {
  public:
   MOCK_METHOD(
       std::unique_ptr<PlaintextReadRecordLayer>,
@@ -236,11 +257,11 @@ class MockFactory : public OpenSSLFactory {
   MOCK_METHOD(uint32_t, makeTicketAgeAdd, (), (const));
 
   MOCK_METHOD(
-      std::shared_ptr<PeerCert>,
+      std::unique_ptr<PeerCert>,
       _makePeerCert,
       (CertificateEntry & entry, bool leaf),
       (const));
-  std::shared_ptr<PeerCert> makePeerCert(CertificateEntry entry, bool leaf)
+  std::unique_ptr<PeerCert> makePeerCert(CertificateEntry entry, bool leaf)
       const override {
     return _makePeerCert(entry, leaf);
   }
@@ -317,7 +338,7 @@ class MockFactory : public OpenSSLFactory {
   }
 };
 
-class MockAsyncKexFactory : public OpenSSLFactory {
+class MockAsyncKexFactory : public openssl::OpenSSLFactory {
  public:
   MOCK_METHOD(
       std::unique_ptr<KeyExchange>,
