@@ -354,6 +354,13 @@ enum class NamedGroup : uint16_t {
   secp256r1_kyber768_draft00 = 25498,
 
   // experimental
+  /**
+   * Internal equivalent of x25519_kyber768 and x25519_kyber512 to get clean
+   * data for external traffic experiments
+   */
+  x25519_kyber768_experimental = 65024,
+  x25519_kyber512_experimental = 65025,
+
   /**
    * Hybrid of secp521r1 and x25519. TLS Supported Group 510 is reserved for
    * private use, see
