@@ -22,6 +22,7 @@
 #include <folly/Overload.h>
 #include <folly/tracing/StaticTracepoint.h>
 #include <algorithm>
+#include <set>
 
 using folly::Optional;
 using folly::SemiFuture;
@@ -74,7 +75,7 @@ FIZZ_DECLARE_EVENT_HANDLER(
     StateEnum::ExpectingCertificate,
     Event::Certificate,
     StateEnum::ExpectingCertificateVerify,
-    StateEnum::ExpectingFinished)
+    StateEnum::ExpectingFinished);
 
 FIZZ_DECLARE_EVENT_HANDLER(
     ServerTypes,
@@ -690,7 +691,7 @@ static void validateGroups(const std::vector<KeyShareEntry>& client_shares) {
 }
 
 static std::tuple<NamedGroup, Optional<Buf>> negotiateGroup(
-    ProtocolVersion version,
+    ProtocolVersion /*version*/,
     const ClientHello& chlo,
     const std::vector<NamedGroup>& supportedGroups) {
   auto groups = getExtension<SupportedGroups>(chlo.extensions);
@@ -747,7 +748,7 @@ static HelloRetryRequest getHelloRetryRequest(
     CipherSuite cipher,
     NamedGroup group,
     Buf legacySessionId,
-    HandshakeContext& handshakeContext) {
+    HandshakeContext& /*handshakeContext*/) {
   HelloRetryRequest hrr;
   hrr.legacy_version = ProtocolVersion::tls_1_2;
   hrr.legacy_session_id_echo = std::move(legacySessionId);
@@ -1022,23 +1023,27 @@ static Buf getCertificateVerify(
   return encodedCertificateVerify;
 }
 
-static Buf getCertificateRequest(
+static std::pair<std::vector<ExtensionType>, Buf> getCertificateRequest(
     const std::vector<SignatureScheme>& acceptableSigSchemes,
     const CertificateVerifier* const verifier,
     HandshakeContext& handshakeContext) {
+  std::vector<ExtensionType> certReqExtensions;
   CertificateRequest request;
   SignatureAlgorithms algos;
   algos.supported_signature_algorithms = acceptableSigSchemes;
+  certReqExtensions.push_back(algos.extension_type);
   request.extensions.push_back(encodeExtension(std::move(algos)));
   if (verifier) {
     auto verifierExtensions = verifier->getCertificateRequestExtensions();
     for (auto& ext : verifierExtensions) {
+      certReqExtensions.push_back(ext.extension_type);
       request.extensions.push_back(std::move(ext));
     }
   }
   auto encodedCertificateRequest = encodeHandshake(std::move(request));
   handshakeContext.appendToTranscript(encodedCertificateRequest);
-  return encodedCertificateRequest;
+  return std::make_pair(
+      std::move(certReqExtensions), std::move(encodedCertificateRequest));
 }
 
 static std::string getSNI(const ClientHello& chlo) {
@@ -1649,11 +1654,13 @@ EventHandler<ServerTypes, StateEnum::ExpectingClientHello, Event::ClientHello>::
                       ClientAuthMode::None &&
                   !resState;
               Optional<Buf> encodedCertRequest;
+              std::vector<ExtensionType> certReqExtensions;
               if (requestClientAuth) {
-                encodedCertRequest = getCertificateRequest(
-                    state.context()->getSupportedSigSchemes(),
-                    state.context()->getClientCertVerifier().get(),
-                    *handshakeContext);
+                std::tie(certReqExtensions, encodedCertRequest) =
+                    getCertificateRequest(
+                        state.context()->getSupportedSigSchemes(),
+                        state.context()->getClientCertVerifier().get(),
+                        *handshakeContext);
               }
 
               /*
@@ -1729,6 +1736,7 @@ EventHandler<ServerTypes, StateEnum::ExpectingClientHello, Event::ClientHello>::
                    encodedCertificate = std::move(encodedCertificate),
                    encodedCertRequest = std::move(encodedCertRequest),
                    requestClientAuth,
+                   certReqExtensions = std::move(certReqExtensions),
                    pskType,
                    pskMode,
                    sigScheme,
@@ -1875,7 +1883,8 @@ EventHandler<ServerTypes, StateEnum::ExpectingClientHello, Event::ClientHello>::
                          echStatus,
                          echState = std::move(echState),
                          clientRandom = std::move(clientRandom),
-                         handshakeTime = std::move(handshakeTime)](
+                         handshakeTime = std::move(handshakeTime),
+                         certReqExtensions = std::move(certReqExtensions)](
                             State& newState) mutable {
                           newState.writeRecordLayer() =
                               std::move(appTrafficWriteRecordLayer);
@@ -1905,6 +1914,8 @@ EventHandler<ServerTypes, StateEnum::ExpectingClientHello, Event::ClientHello>::
                           newState.clientRandom() = std::move(clientRandom);
                           newState.echStatus() = echStatus;
                           newState.echState() = std::move(echState);
+                          newState.certReqExtensions() =
+                              std::move(certReqExtensions);
                         });
 
                     if (earlyDataType == EarlyDataType::Accepted) {
@@ -1993,7 +2004,7 @@ EventHandler<ServerTypes, StateEnum::AcceptingEarlyData, Event::AppWrite>::
   auto& appWrite = *param.asAppWrite();
 
   WriteToSocket write;
-  write.callback = appWrite.callback;
+  write.token = appWrite.token;
   write.contents.emplace_back(state.writeRecordLayer()->writeAppData(
       std::move(appWrite.data), appWrite.aeadOptions));
   write.flags = appWrite.flags;
@@ -2030,7 +2041,7 @@ EventHandler<ServerTypes, StateEnum::ExpectingFinished, Event::AppWrite>::
   auto& appWrite = *param.asAppWrite();
 
   WriteToSocket write;
-  write.callback = appWrite.callback;
+  write.token = appWrite.token;
   write.contents.emplace_back(state.writeRecordLayer()->writeAppData(
       std::move(appWrite.data), appWrite.aeadOptions));
   write.flags = appWrite.flags;
@@ -2129,14 +2140,9 @@ EventHandler<ServerTypes, StateEnum::ExpectingCertificate, Event::Certificate>::
 
   std::vector<std::shared_ptr<const PeerCert>> clientCerts;
   bool leaf = true;
+  const auto& certExtensionsSupported = state.certReqExtensions();
   for (auto& certEntry : certMsg.certificate_list) {
-    // We don't request any extensions, so this ought to be empty
-    if (!certEntry.extensions.empty()) {
-      throw FizzException(
-          "certificate extensions must be empty",
-          AlertDescription::illegal_parameter);
-    }
-
+    Protocol::checkAllowedExtensions(certEntry, certExtensionsSupported);
     clientCerts.emplace_back(state.context()->getFactory()->makePeerCert(
         std::move(certEntry), leaf));
     leaf = false;
@@ -2337,7 +2343,7 @@ EventHandler<ServerTypes, StateEnum::AcceptingData, Event::AppWrite>::handle(
   auto& appWrite = *param.asAppWrite();
 
   WriteToSocket write;
-  write.callback = appWrite.callback;
+  write.token = appWrite.token;
   write.contents.emplace_back(state.writeRecordLayer()->writeAppData(
       std::move(appWrite.data), appWrite.aeadOptions));
   write.flags = appWrite.flags;
